==> vmp-0.7.3.tar.xz: vmp-0.7.3/framework/python/vmp_jrp/__init__.py <==
#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 03/01/2025

import vmp
import vmp_net
import vmp_event
import vmp_crypto 

from vmp_jrp_  import protoname_ as protoname_

from vmp_jrp_  import status_ok                    as status_ok
from vmp_jrp_  import status_err                   as status_err
from vmp_jrp_  import status_malformed_msg         as status_malformed_msg
from vmp_jrp_  import status_undef_datatype        as status_undef_datatype
from vmp_jrp_  import status_accessdenied          as status_accessdenied
from vmp_jrp_  import status_duplexsession         as status_duplexsession
from vmp_jrp_  import status_protocolbad           as status_protocolbad
from vmp_jrp_  import status_closeconnection       as status_closeconnection
from vmp_jrp_  import status_timeout               as status_timeout
from vmp_jrp_  import status_killed                as status_killed
from vmp_jrp_  import status_input_bad             as status_input_bad
from vmp_jrp_  import status_push_bad              as status_push_bad
from vmp_jrp_  import status_input_notmanaged      as status_input_notmanaged
from vmp_jrp_  import status_rid_duplex            as status_rid_duplex
from vmp_jrp_  import status_resource_busy         as status_resource_busy
from vmp_jrp_  import status_resource_accessdenied as status_resource_accessdenied
from vmp_jrp_  import status_kill_notcomplete      as status_kill_notcomplete
from vmp_jrp_  import status_forward_denied        as status_forward_denied
from vmp_jrp_  import status_request_overflow      as status_request_overflow

from vmp_jrp_  import min_permits as min_permits
from vmp_jrp_  import max_permits as max_permits

from vmp_jrp_  import msg_status as msg_status

from vmp_jrp_  import JrpCommon        as JrpCommon
from vmp_jrp_  import sessiontype      as sessiontype
from vmp_jrp_  import sessionid        as sessionid
from vmp_jrp_  import sessionpermits   as sessionpermits

from vmp_jrp_  import JrpReq    as JrpReq
from vmp_jrp_  import misc      as misc
from vmp_jrp_  import jrpui     as jrpui
from vmp_jrp_  import JrpUI     as JrpUI
from vmp_jrp_  import WssJrpUI  as WssJrpUI
from vmp_jrp_  import wssjrpui  as wssjrpui

from .client   import Plugin      as Client
from .client   import PluginTopic as ClientTopic

==> vmp-0.8.1.tar.xz: vmp-0.8.1/framework/python/vmp_jrp/__init__.py <==
#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 09/05/2025

import vmp
import vmp_net
import vmp_event
import vmp_crypto 

from vmp_jrp_  import protoname_ as protoname_

from vmp_jrp_  import status_ok                    as status_ok
from vmp_jrp_  import status_err                   as status_err
from vmp_jrp_  import status_malformed_msg         as status_malformed_msg
from vmp_jrp_  import status_undef_datatype        as status_undef_datatype
from vmp_jrp_  import status_accessdenied          as status_accessdenied
from vmp_jrp_  import status_duplexsession         as status_duplexsession
from vmp_jrp_  import status_protocolbad           as status_protocolbad
from vmp_jrp_  import status_closeconnection       as status_closeconnection
from vmp_jrp_  import status_timeout               as status_timeout
from vmp_jrp_  import status_killed                as status_killed
from vmp_jrp_  import status_input_bad             as status_input_bad
from vmp_jrp_  import status_push_bad              as status_push_bad
from vmp_jrp_  import status_input_notmanaged      as status_input_notmanaged
from vmp_jrp_  import status_rid_duplex            as status_rid_duplex
from vmp_jrp_  import status_resource_busy         as status_resource_busy
from vmp_jrp_  import status_resource_accessdenied as status_resource_accessdenied
from vmp_jrp_  import status_kill_notcomplete      as status_kill_notcomplete
from vmp_jrp_  import status_forward_denied        as status_forward_denied
from vmp_jrp_  import status_request_overflow      as status_request_overflow
from vmp_jrp_  import status_resource_notfound     as status_resource_notfound
from vmp_jrp_  import status_request_timeout       as status_request_timeout
from vmp_jrp_  import status_managed_timeout       as status_managed_timeout
from vmp_jrp_  import status_accesspeerdenied      as status_accesspeerdenied 
from vmp_jrp_  import status_internal              as status_internal 
from vmp_jrp_  import status_resource_killed       as status_resource_killed 

from vmp_jrp_  import min_permits as min_permits
from vmp_jrp_  import max_permits as max_permits

from vmp_jrp_  import msg_status as msg_status

from vmp_jrp_  import JrpCommon        as JrpCommon
from vmp_jrp_  import sessiontype      as sessiontype
from vmp_jrp_  import sessionid        as sessionid
from vmp_jrp_  import sessionpermits   as sessionpermits

from vmp_jrp_  import JrpReq    as JrpReq
from vmp_jrp_  import misc      as misc
from vmp_jrp_  import jrpui     as jrpui
from vmp_jrp_  import JrpUI     as JrpUI
from vmp_jrp_  import WssJrpUI  as WssJrpUI
from vmp_jrp_  import wssjrpui  as wssjrpui

from .client   import Plugin      as Client
from .client   import PluginTopic as ClientTopic
